==> checker-3.32.0.jar: annotated-jdk/src/java.base/share/classes/javax/crypto/CryptoPolicyParser.java <==
/*
 * Copyright (c) 1999, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package javax.crypto;

import org.checkerframework.dataflow.qual.Pure;
import java.io.*;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;
import static java.util.Locale.ENGLISH;
import java.security.GeneralSecurityException;
import java.security.spec.AlgorithmParameterSpec;
import java.lang.reflect.*;

final class CryptoPolicyParser {

    void read(Reader policy) throws ParsingException, IOException;

    CryptoPermission[] getPermissions();

    private static class GrantEntry {

        void add(CryptoPermissionEntry pe);

        boolean remove(CryptoPermissionEntry pe);

        @Pure
        boolean contains(CryptoPermissionEntry pe);

        Enumeration<CryptoPermissionEntry> permissionElements();
    }

    private static class CryptoPermissionEntry {

        public int hashCode();

        public boolean equals(Object obj);
    }

    static final class ParsingException extends GeneralSecurityException {
    }
}

==> checker-3.51.0.jar: annotated-jdk/src/java.base/share/classes/javax/crypto/CryptoPolicyParser.java <==
/*
 * Copyright (c) 1999, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package javax.crypto;

import org.checkerframework.checker.nonempty.qual.EnsuresNonEmptyIf;
import org.checkerframework.dataflow.qual.Pure;
import java.io.*;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;
import static java.util.Locale.ENGLISH;
import java.security.GeneralSecurityException;
import java.security.spec.AlgorithmParameterSpec;
import java.lang.reflect.*;

final class CryptoPolicyParser {

    void read(Reader policy) throws ParsingException, IOException;

    CryptoPermission[] getPermissions();

    private static class GrantEntry {

        void add(CryptoPermissionEntry pe);

        boolean remove(CryptoPermissionEntry pe);

        @Pure
        @EnsuresNonEmptyIf(result = true, expression = "this")
        boolean contains(CryptoPermissionEntry pe);

        Enumeration<CryptoPermissionEntry> permissionElements();
    }

    private static class CryptoPermissionEntry {

        public int hashCode();

        public boolean equals(Object obj);
    }

    static final class ParsingException extends GeneralSecurityException {
    }
}
